GitInitOutcome class final

Constructors

GitInitOutcome({required bool skipped, required bool ranInit, required bool failed, int? exitCode, String? output})
const

Properties

exitCode int?
final
failed bool
final
hashCode int
The hash code for this object.
no setterinherited
output String?
final
ranInit bool
final
runtimeType Type
A representation of the runtime type of the object.
no setterinherited
skipped bool
final

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toString() String
A string representation of this object.
inherited

Operators

operator ==(Object other) bool
The equality operator.
inherited