RegenFailure class final

Constructors

RegenFailure({required String failingCommand, required int exitCode, required String output, required List<String> manualActions})
const

Properties

exitCode int
final
failingCommand String
final
hashCode int
The hash code for this object.
no setterinherited
manualActions List<String>
final
output String
final
runtimeType Type
A representation of the runtime type of the object.
no setterinherited

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toJson() Map<String, Object>
toString() String
A string representation of this object.
inherited

Operators

operator ==(Object other) bool
The equality operator.
inherited