ApplyPhase2Result class final

Constructors

ApplyPhase2Result({required List<String> commands, required List<String> pathsTouched, required List<String> outsideDeclaredSet, RegenFailure? failure})
const

Properties

commands List<String>
final
failure RegenFailure?
final
hashCode int
The hash code for this object.
no setterinherited
ok bool
no setter
outsideDeclaredSet List<String>
final
pathsTouched List<String>
final
runtimeType Type
A representation of the runtime type of the object.
no setterinherited

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toString() String
A string representation of this object.
inherited

Operators

operator ==(Object other) bool
The equality operator.
inherited