ApplyPipelineResult class final

Constructors

ApplyPipelineResult({required int exitCode, required bool ok, required Map<String, dynamic> result, required Map<String, dynamic>? error, required String textLine})
const

Properties

error Map<String, dynamic>?
final
exitCode int
final
hashCode int
The hash code for this object.
no setterinherited
ok bool
final
result Map<String, dynamic>
final
runtimeType Type
A representation of the runtime type of the object.
no setterinherited
textLine String
final

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toString() String
A string representation of this object.
inherited

Operators

operator ==(Object other) bool
The equality operator.
inherited