CreateCommand class
Constructors
- CreateCommand({DoctorProbe? doctorProbe, RecipeLock? recipeLock, Catalog? catalog, StagePlan? stagePlan, PlanStore? planStore, WizardIo wizardIo = const ConsoleWizardIo(), Clock? clock, HeartbeatStarter? heartbeatStarter, bool isCancelled()?, void out(String)?, void diagnostics(String)?, ProcessRunner? processRunner, AppliedHistoryStore? historyStore, ProjectValidator? validate, void releaseStaging(String)?, InputReader? inputReader, String? sessionLockBaseDir})
Properties
-
aliases
→ List<
String> -
Alternate names for this command.
no setterinherited
- argParser → ArgParser
-
The argument parser for this command.
no setterinherited
- argResults → ArgResults?
-
The parsed argument results for this command.
no setterinherited
- catalog → Catalog?
-
final
- category → String
-
The command's category.
no setterinherited
- clock → Clock
-
final
- description → String
-
A description of this command, included in usage.
final
- diagnostics → void Function(String)
-
final
- doctorProbe → DoctorProbe?
-
final
- globalResults → ArgResults?
-
The parsed global argument results.
no setterinherited
- hashCode → int
-
The hash code for this object.
no setterinherited
- heartbeatStarter → HeartbeatStarter
-
final
-
Whether or not this command should be hidden from help listings.
no setterinherited
- historyStore → AppliedHistoryStore
-
final
- inputReader → InputReader
-
final
- invocation → String
-
A single-line template for how to invoke this command (e.g.
"pub getpackage").no setterinherited - isCancelled ↔ bool Function()
-
latefinal
- name → String
-
The name of this command.
final
- out → void Function(String)
-
final
-
parent
→ Command<
int> ? -
The command's parent command, if this is a subcommand.
no setterinherited
- planStore → PlanStore
-
final
- processRunner → ProcessRunner
-
final
- recipeLock → RecipeLock?
-
final
- releaseStagingCallback → void Function(String)
-
final
-
runner
→ CommandRunner<
int> ? -
The command runner for this command.
no setterinherited
- runtimeType → Type
-
A representation of the runtime type of the object.
no setterinherited
- sessionLockBaseDir → String?
-
final
- stagePlan → StagePlan
-
final
-
subcommands
→ Map<
String, Command< int> > -
An unmodifiable view of all sublevel commands of this command.
no setterinherited
-
suggestionAliases
→ List<
String> -
Alternate non-functional names for this command.
no setterinherited
- summary → String
-
A short description of this command, included in
parent'sCommandRunner.usage.no setterinherited - takesArguments → bool
-
Whether or not this command takes positional arguments in addition to
options.
no setterinherited
- usage → String
-
Generates a string displaying usage information for this command.
no setterinherited
-
An optional footer for
usage.no setterinherited - validate → ProjectValidator
-
final
- wizardIo → WizardIo
-
final
Methods
-
addSubcommand(
Command< int> command) → void -
Adds
Commandas a subcommand of this.inherited -
noSuchMethod(
Invocation invocation) → dynamic -
Invoked when a nonexistent method or property is accessed.
inherited
-
printUsage(
) → void -
Prints the usage information for this command.
inherited
-
run(
) → Future< int> -
Runs this command.
override
-
toString(
) → String -
A string representation of this object.
inherited
-
usageException(
String message) → Never -
Throws a
UsageExceptionwithmessage.inherited
Operators
-
operator ==(
Object other) → bool -
The equality operator.
inherited