Properties
- hashCode → int
-
The hash code for this object.
no setterinherited
- runtimeType → Type
-
A representation of the runtime type of the object.
no setterinherited
Methods
-
noSuchMethod(
Invocation invocation) → dynamic -
Invoked when a nonexistent method or property is accessed.
inherited
-
toString(
) → String -
A string representation of this object.
inherited
Operators
-
operator ==(
Object other) → bool -
The equality operator.
inherited
Constants
- applyFailedPartialRecoveryOrManualRequired → const int
- applyFailedRolledBack → const int
- approvalRequiredAndAbsent → const int
- blueprintInvalidOrCompatibilityBlocker → const int
- cancelledByUser → const int
- environmentPreflightFailure → const int
- planningOrStagingFailure → const int
- planNotFoundOrStateForbids → const int
- planStaleOrStagingIntegrityFailure → const int
- sessionLockHeld → const int
- success → const int
- unexpectedInternalError → const int
- usageError → const int
- validationFailed → const int