RecipeMetadata class

Constructors

RecipeMetadata({String flutterSdkRequirement = '>=3.41.0 <3.42.0', String recipeId = 'standard_app', String recipeVersion = '0.1.0', String engineVersion = '0.1.0', Set<String> integrations = const {'Feature First', 'Bloc/Cubit', 'GoRouter', 'GetIt', 'Dio', 'Freezed', 'json_serializable', 'build_runner'}, Map<String, dynamic> toolchainPolicy = const {}})
const

Properties

engineVersion String
final
flutterSdkRequirement String
final
hashCode int
The hash code for this object.
no setterinherited
integrations Set<String>
final
recipeId String
final
recipeVersion String
final
runtimeType Type
A representation of the runtime type of the object.
no setterinherited
toolchainPolicy Map<String, dynamic>
final

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toString() String
A string representation of this object.
inherited

Operators

operator ==(Object other) bool
The equality operator.
inherited