ConsoleWizardIo class
The production implementation of WizardIo that uses standard input/output.
- Implemented types
Constructors
- ConsoleWizardIo()
-
const
Properties
- hashCode → int
-
The hash code for this object.
no setterinherited
- runtimeType → Type
-
A representation of the runtime type of the object.
no setterinherited
Methods
-
noSuchMethod(
Invocation invocation) → dynamic -
Invoked when a nonexistent method or property is accessed.
inherited
-
prompt(
String question) → String -
Prompts the user with a question and returns their trimmed input line.
override
-
toString(
) → String -
A string representation of this object.
inherited
-
writeLine(
String message) → void -
Writes a line of message to the console.
override
Operators
-
operator ==(
Object other) → bool -
The equality operator.
inherited