WizardIo class abstract interface

Input/Output abstraction for the wizard to allow test injection.

Implementers

Properties

hashCode int
The hash code for this object.
no setterinherited
runtimeType Type
A representation of the runtime type of the object.
no setterinherited

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
prompt(String question) String
Prompts the user with a question and returns their trimmed input line.
toString() String
A string representation of this object.
inherited
writeLine(String message) → void
Writes a line of message to the console.

Operators

operator ==(Object other) bool
The equality operator.
inherited