InvalidUtf8 class

Exception thrown when invalid UTF-8 content is encountered.

Binds: FR-104.

Implemented types

Constructors

InvalidUtf8(String message, [List<int>? bytes])
const

Properties

bytes List<int>?
final
hashCode int
The hash code for this object.
no setterinherited
message String
final
runtimeType Type
A representation of the runtime type of the object.
no setterinherited

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toString() String
A string representation of this object.
override

Operators

operator ==(Object other) bool
The equality operator.
inherited