InvalidUtf8Result class

Result returned when a file expected to be text contains invalid UTF-8.

Inheritance

Constructors

InvalidUtf8Result({required String message, required List<int> bytes})
const

Properties

bytes List<int>
final
hashCode int
The hash code for this object.
no setteroverride
message String
final
runtimeType Type
A representation of the runtime type of the object.
no setterinherited

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toString() String
A string representation of this object.
override

Operators

operator ==(Object other) bool
The equality operator.
override