SessionLock class
Manages a user-scoped session lock for serializing FlutterStart operations against a canonical destination path.
Binds: FR-056, FR-056a.
Properties
- canonicalDestination → String
-
final
- destinationPath → String
-
final
- hashCode → int
-
The hash code for this object.
no setterinherited
- lockFilePath → String
-
final
- pid → int
-
final
- runtimeType → Type
-
A representation of the runtime type of the object.
no setterinherited
Methods
-
noSuchMethod(
Invocation invocation) → dynamic -
Invoked when a nonexistent method or property is accessed.
inherited
-
release(
) → Future< void> - Releases the lock.
-
releaseSync(
) → void - Releases the lock synchronously.
-
toString(
) → String -
A string representation of this object.
inherited
Operators
-
operator ==(
Object other) → bool -
The equality operator.
inherited