SessionLockHeldException class
Exception thrown when a session lock is already held by another live operation.
Binds: FR-056, ExitCodes.sessionLockHeld.
- Implemented types
Constructors
- SessionLockHeldException({required String message, required String canonicalDestination, required int holdingPid, int exitCode = ExitCodes.sessionLockHeld})
Properties
- canonicalDestination → String
-
final
- exitCode → int
-
final
- hashCode → int
-
The hash code for this object.
no setterinherited
- holdingPid → int
-
final
- message → String
-
final
- runtimeType → Type
-
A representation of the runtime type of the object.
no setterinherited
Methods
-
noSuchMethod(
Invocation invocation) → dynamic -
Invoked when a nonexistent method or property is accessed.
inherited
-
toString(
) → String -
A string representation of this object.
override
Operators
-
operator ==(
Object other) → bool -
The equality operator.
inherited