writeAll method
Writes the elements of objects separated by separator.
Writes the string representation of every element of objects,
in iteration order, and writes separator between any two elements.
sink.writeAll(["Hello", "World"], " Beautiful ");
is equivalent to:
sink
..write("Hello");
..write(" Beautiful ");
..write("World");
Implementation
@override
void writeAll(Iterable objects, [String separator = '']) {
final formatted = objects
.map((obj) => redactText(obj?.toString() ?? ''))
.join(separator);
_inner.write(formatted);
}