PruneResult class

The result of the log pruning execution.

Constructors

PruneResult({required List<String> pathsToPrune, String? warning})
Creates a new PruneResult.

Properties

hashCode int
The hash code for this object.
no setterinherited
pathsToPrune List<String>
The paths of plan logs that should be deleted/pruned.
final
runtimeType Type
A representation of the runtime type of the object.
no setterinherited
warning String?
An optional warning message if an error occurred during pruning.
final

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toString() String
A string representation of this object.
inherited

Operators

operator ==(Object other) bool
The equality operator.
inherited