ObservedValue<T> class

Represents a value that may or may not have been observed during a probe.

Binds: INV-D1, FR-009, SC-019.

Constructors

ObservedValue({required bool observed, T? value})
const
ObservedValue.fromJson(Map<String, dynamic> json, T fromJsonT(dynamic))
factory
ObservedValue.observed(T val)
const
ObservedValue.unobserved()
const

Properties

hashCode int
The hash code for this object.
no setteroverride
observed bool
final
runtimeType Type
A representation of the runtime type of the object.
no setterinherited
value → T?
final

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toJson([Object? customSerializer(T)?]) Map<String, dynamic>
toString() String
A string representation of this object.
inherited

Operators

operator ==(Object other) bool
The equality operator.
override