OwnershipClass enum

Represents the ownership classification of a file.

Binds: FR-092, INV-W1, INV-W2.

Inheritance
Available extensions

Values

flutterStartOwned → const OwnershipClass

Files owned and managed exclusively by FlutterStart.

shared → const OwnershipClass

Files shared between FlutterStart and the user.

userOwned → const OwnershipClass

Files owned and managed by the user.

toolchainGeneratedHostDependent → const OwnershipClass

Host-path-dependent files generated by the toolchain.

Properties

hashCode int
The hash code for this object.
no setterinherited
index int
A numeric identifier for the enumerated value.
no setterinherited
inReviewedContentInvariant bool
Whether this class of file is included in the reviewed-content invariant.
no setter
isMaterialized bool
Whether this class of file is materialized (written to destination).
no setter
isUserSource bool
Whether this class of file can be classified or treated as user source.
no setter
name String

Available on Enum, provided by the EnumName extension

The name of the enum value.
no setter
runtimeType Type
A representation of the runtime type of the object.
no setterinherited

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toString() String
A string representation of this object.
inherited

Operators

operator ==(Object other) bool
The equality operator.
inherited

Constants

values → const List<OwnershipClass>
A constant List of the values in this enum, in order of their declaration.