RecipeLock class
The recipe lock pinning the concrete versions of all components.
Binds: FR-032–FR-036, INV-L1/L2.
Constructors
-
RecipeLock({required int schemaVersion, required String engineVersion, required String recipeId, required String recipeVersion, required String rendererVersion, required Map<
String, String> directDependencies, required String resolvedLock, required String flutterRange, required String dartRange, required Map<String, dynamic> compatibilityData, required Map<String, List< hostDependentExclusions})String> > -
RecipeLock.fromJson(Map<
String, dynamic> json) -
factory
Properties
-
compatibilityData
→ Map<
String, dynamic> -
final
- dartRange → String
-
final
-
directDependencies
→ Map<
String, String> -
final
- engineVersion → String
-
final
- flutterRange → String
-
final
- hashCode → int
-
The hash code for this object.
no setterinherited
- hasNoCaretConstraints → bool
-
Returns true if directDependencies has no caret (^) constraints (INV-L1).
no setter
-
hostDependentExclusions
→ Map<
String, List< String> > -
final
- recipeId → String
-
final
- recipeVersion → String
-
final
- rendererVersion → String
-
final
- resolvedLock → String
-
final
- runtimeType → Type
-
A representation of the runtime type of the object.
no setterinherited
- schemaVersion → int
-
final
Methods
-
noSuchMethod(
Invocation invocation) → dynamic -
Invoked when a nonexistent method or property is accessed.
inherited
-
toJson(
) → Map< String, dynamic> -
toString(
) → String -
A string representation of this object.
inherited
Operators
-
operator ==(
Object other) → bool -
The equality operator.
inherited