ProcessRunner class

Process runner wrapping dart:io process execution.

Binds: FR-055.

Constructors

ProcessRunner()
const

Properties

hashCode int
The hash code for this object.
no setterinherited
runtimeType Type
A representation of the runtime type of the object.
no setterinherited

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
run(String executable, List<String> arguments, {String? workingDirectory, Map<String, String>? environment, bool includeParentEnvironment = true}) Future<ProcessResult>
Runs the process to completion and returns the result.
start(String executable, List<String> arguments, {String? workingDirectory, Map<String, String>? environment, bool includeParentEnvironment = true, ProcessStartMode mode = ProcessStartMode.normal}) Future<Process>
Starts a process in the background.
toString() String
A string representation of this object.
inherited

Operators

operator ==(Object other) bool
The equality operator.
inherited