StalenessInputs class final

Recorded plan values and current read-only observations used for staleness.

Constructors

StalenessInputs({required String recordedManifestHash, required Map<String, String> recordedNormalizedHashes, required String recordedBlueprintHash, required String recordedRecipeVersion, required String recordedEngineVersion, required Map<String, String> recordedRelevantPubspecHashes, required String currentManifestHash, required Map<String, String?> currentNormalizedHashes, required String currentBlueprintHash, required String currentRecipeVersion, required String currentEngineVersion, required Map<String, String?> currentRelevantPubspecHashes, List<String> unrelatedChangedPaths = const []})
const

Properties

currentBlueprintHash String
final
currentEngineVersion String
final
currentManifestHash String
final
currentNormalizedHashes Map<String, String?>
final
currentRecipeVersion String
final
currentRelevantPubspecHashes Map<String, String?>
final
hashCode int
The hash code for this object.
no setterinherited
recordedBlueprintHash String
final
recordedEngineVersion String
final
recordedManifestHash String
final
recordedNormalizedHashes Map<String, String>
final
recordedRecipeVersion String
final
recordedRelevantPubspecHashes Map<String, String>
final
runtimeType Type
A representation of the runtime type of the object.
no setterinherited
unrelatedChangedPaths List<String>
final

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toString() String
A string representation of this object.
inherited

Operators

operator ==(Object other) bool
The equality operator.
inherited