TemplateVariableSchema class

Closed template variable schema per FR-046.

Templates may reference ONLY these Blueprint-derived variables.

Properties

hashCode int
The hash code for this object.
no setterinherited
runtimeType Type
A representation of the runtime type of the object.
no setterinherited

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toString() String
A string representation of this object.
inherited

Operators

operator ==(Object other) bool
The equality operator.
inherited

Static Properties

allVariables Set<String>
All allowed variable names in the closed schema.
no setter

Static Methods

isAllowedVariable(String name) bool
Checks if name is in the allowed schema.
isBooleanVariable(String name) bool
Checks if name is a valid boolean variable.
isStringVariable(String name) bool
Checks if name is a valid string variable.

Constants

booleanVariables → const Set<String>
Allowed boolean variable names (conditionals only).
stringVariables → const Set<String>
Allowed string variable names (substitution only).