GateOutcome class final

Constructors

GateOutcome({required List<CommandRecord> commands, required List<int> exitCodes, required List<String> outputs, required bool passed})

Properties

commands List<CommandRecord>
final
exitCodes List<int>
final
hashCode int
The hash code for this object.
no setterinherited
outputs List<String>
final
passed bool
final
runtimeType Type
A representation of the runtime type of the object.
no setterinherited

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toString() String
A string representation of this object.
inherited

Operators

operator ==(Object other) bool
The equality operator.
inherited