ApplyFileSystem class

Constructors

ApplyFileSystem({void onEvent(ApplyFileEvent event, String path)?})
const

Properties

hashCode int
The hash code for this object.
no setterinherited
onEvent → void Function(ApplyFileEvent event, String path)?
final
runtimeType Type
A representation of the runtime type of the object.
no setterinherited

Methods

createDirectory(String path) → void
deleteFile(String path) → void
destinationWritable(String path) bool
directoryEmpty(String path) bool
directoryExists(String path) bool
fileExists(String path) bool
noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
readBytes(String path) List<int>
replace(String temporaryPath, String targetPath) → void
toString() String
A string representation of this object.
inherited
writeNew(String path, List<int> bytes) → void
writeTemp(String path, List<int> bytes) → void

Operators

operator ==(Object other) bool
The equality operator.
inherited