ApplyObservations class final
Constructors
- ApplyObservations({required String manifestHash, required String blueprintHash, required String recipeVersion, required String engineVersion})
-
const
Properties
- blueprintHash → String
-
final
- engineVersion → String
-
final
- hashCode → int
-
The hash code for this object.
no setterinherited
- manifestHash → String
-
final
- recipeVersion → String
-
final
- runtimeType → Type
-
A representation of the runtime type of the object.
no setterinherited
Methods
-
noSuchMethod(
Invocation invocation) → dynamic -
Invoked when a nonexistent method or property is accessed.
inherited
-
toString(
) → String -
A string representation of this object.
inherited
Operators
-
operator ==(
Object other) → bool -
The equality operator.
inherited