Section class
A single Customize section: its display title and, for catalog-driven sections, the capability it selects from and whether Skip clears it (FR-007-FR-009).
Constructors
-
Section({required SectionKind kind, required String title, String? capabilityId, List<
String> capabilityIds = const [], SelectionType? selectionType, bool optional = false}) -
const
Properties
- capabilityId → String?
-
final
-
capabilityIds
→ List<
String> -
final
- hashCode → int
-
The hash code for this object.
no setterinherited
- isCatalogDriven → bool
-
no setter
- kind → SectionKind
-
final
- optional → bool
-
final
- runtimeType → Type
-
A representation of the runtime type of the object.
no setterinherited
- selectionType → SelectionType?
-
final
- title → String
-
final
Methods
-
noSuchMethod(
Invocation invocation) → dynamic -
Invoked when a nonexistent method or property is accessed.
inherited
-
toString(
) → String -
A string representation of this object.
inherited
Operators
-
operator ==(
Object other) → bool -
The equality operator.
inherited