ExitCodes class abstract final

Stable exit codes for the FlutterStart application.

Binds: FR-144, SC-008.

Properties

hashCode int
The hash code for this object.
no setterinherited
runtimeType Type
A representation of the runtime type of the object.
no setterinherited

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toString() String
A string representation of this object.
inherited

Operators

operator ==(Object other) bool
The equality operator.
inherited

Constants

applyFailedPartialRecoveryOrManualRequired → const int
Apply failed — Partial Recovery or Manual Recovery Required (10)
applyFailedRolledBack → const int
Apply failed — Rolled Back (9)
approvalRequiredAndAbsent → const int
Approval required and absent (8)
blueprintInvalidOrCompatibilityBlocker → const int
Blueprint invalid or compatibility blocker (4)
cancelledByUser → const int
Cancelled by user (12)
environmentPreflightFailure → const int
Environment preflight failure (3)
planningOrStagingFailure → const int
Planning or staging failure (includes generation-validity failure) (5)
planNotFoundOrStateForbids → const int
Plan not found, or plan in a state that forbids the operation (6)
planStaleOrStagingIntegrityFailure → const int
Plan stale, or staging integrity failure — Apply blocked (7)
sessionLockHeld → const int
Session lock held by another FlutterStart operation (13)
success → const int
Success (0)
unexpectedInternalError → const int
Unexpected internal error (1)
usageError → const int
Usage error (invalid arguments) (2)
validationFailed → const int
Validation failed (11)