InvalidUtf8Result class
Result returned when a file expected to be text contains invalid UTF-8.
- Inheritance
-
- Object
- HashResult
- InvalidUtf8Result
Constructors
-
InvalidUtf8Result({required String message, required List<
int> bytes}) -
const
Properties
Methods
-
noSuchMethod(
Invocation invocation) → dynamic -
Invoked when a nonexistent method or property is accessed.
inherited
-
toString(
) → String -
A string representation of this object.
override
Operators
-
operator ==(
Object other) → bool -
The equality operator.
override