components/flutterstart_core/src/logging/redaction
library
Classes
-
DenyList
-
A versioned definition containing a set of redaction rules.
-
EnvVarRedactionRule
-
A redaction rule that dynamically redacts values of environment variables
whose names match documented secret-like patterns.
-
RedactionRule
-
Represents a rule used to redact sensitive content from logs and artifacts.
-
RedactionSink
-
A write-time sink wrapper that redacts secrets before writing them to disk.
-
StaticRedactionRule
-
A redaction rule using a regular expression to match and replace secrets.