RedactionSink class
A write-time sink wrapper that redacts secrets before writing them to disk.
Binds: INV-G1, INV-G2.
- Implemented types
Constructors
-
RedactionSink(StringSink _inner, {DenyList? denyList, Map<
String, String> ? environment}) -
Creates a RedactionSink wrapping
_inner.
Properties
- hashCode → int
-
The hash code for this object.
no setterinherited
- runtimeType → Type
-
A representation of the runtime type of the object.
no setterinherited
Methods
-
noSuchMethod(
Invocation invocation) → dynamic -
Invoked when a nonexistent method or property is accessed.
inherited
-
redactArgumentList(
List< String> args) → List<String> - Redacts a command argument list.
-
redactLogRecord(
LogRecord record) → LogRecord - Redacts a LogRecord before serialization.
-
redactText(
String text) → String - Redacts free-text (stdout/stderr).
-
toString(
) → String -
A string representation of this object.
inherited
-
write(
Object? obj) → void -
Writes the string representation of
object.override -
writeAll(
Iterable objects, [String separator = '']) → void -
Writes the elements of
objectsseparated byseparator.override -
writeCharCode(
int charCode) → void -
Writes a string containing the character with code point
charCode.override -
writeln(
[Object? obj = '']) → void -
Writes the string representation of
objectfollowed by a newline.override -
writeLogRecord(
LogRecord record) → void - Writes a redacted LogRecord to the underlying sink as a JSON line.
Operators
-
operator ==(
Object other) → bool -
The equality operator.
inherited