PlanPruneInput class
Input model representing a plan's log metadata for pruning evaluation.
Constructors
- PlanPruneInput({required String planId, required DateTime timestamp, required String path})
- Creates a new PlanPruneInput.
Properties
- hashCode → int
-
The hash code for this object.
no setterinherited
- path → String
-
The absolute or relative path to the plan's log file or directory.
final
- planId → String
-
Unique identifier of the plan.
final
- runtimeType → Type
-
A representation of the runtime type of the object.
no setterinherited
- timestamp → DateTime
-
The timestamp when the plan log was created.
final
Methods
-
noSuchMethod(
Invocation invocation) → dynamic -
Invoked when a nonexistent method or property is accessed.
inherited
-
toString(
) → String -
A string representation of this object.
inherited
Operators
-
operator ==(
Object other) → bool -
The equality operator.
inherited