ChangePlan class
Represents the Change Plan outlining the creation steps and verification constraints.
Binds: data-model.md 4, INV-C1, INV-C2, INV-C4, INV-C5, INV-A3.
Constructors
-
ChangePlan({required String planId, required int schemaVersion, required PlanState state, required String blueprintHash, required String manifestHash, required List<
String> targetPaths, required Map<String, String> reviewedSourceHashes, Map<String, String> reviewedNormalizedHashes = const {}, required String recipeVersion, required String engineVersion, required List<Operation> operations, required Map<String, String> dependencies, required List<CommandRecord> stagingCommands, required List<CommandRecord> regenerationCommands, required List<String> regenerationPathSet, required List<ToolchainException> toolchainExceptions, required List<CommandRecord> validationCommands, required List<String> warnings, required List<String> manualSteps, required RollbackCapability rollbackCapability, required ApprovalRecord? approvalRecord}) -
ChangePlan.fromJson(Map<
String, dynamic> json) -
factory
Properties
- approvalRecord → ApprovalRecord?
-
final
- blueprintHash → String
-
final
-
dependencies
→ Map<
String, String> -
final
- engineVersion → String
-
final
- hashCode → int
-
The hash code for this object.
no setterinherited
- manifestHash → String
-
final
-
manualSteps
→ List<
String> -
final
- operationCount → int
-
Exposes the count of operations (INV-C4).
no setter
-
operations
→ List<
Operation> -
final
- planHash → String
-
Digests the IMMUTABLE REVIEWED CONTENT ONLY (INV-A3).
no setter
- planId → String
-
final
- recipeVersion → String
-
final
-
regenerationCommands
→ List<
CommandRecord> -
final
-
regenerationPathSet
→ List<
String> -
final
-
reviewedNormalizedHashes
→ Map<
String, String> -
final
-
reviewedSourceHashes
→ Map<
String, String> -
final
- rollbackCapability → RollbackCapability
-
final
- runtimeType → Type
-
A representation of the runtime type of the object.
no setterinherited
- schemaVersion → int
-
final
-
stagingCommands
→ List<
CommandRecord> -
final
- state → PlanState
-
final
-
targetPaths
→ List<
String> -
final
-
toolchainExceptions
→ List<
ToolchainException> -
final
-
validationCommands
→ List<
CommandRecord> -
final
-
warnings
→ List<
String> -
final
Methods
-
noSuchMethod(
Invocation invocation) → dynamic -
Invoked when a nonexistent method or property is accessed.
inherited
-
toJson(
) → Map< String, dynamic> -
toString(
) → String -
A string representation of this object.
inherited
Operators
-
operator ==(
Object other) → bool -
The equality operator.
inherited