Operation class
Represents a single unit of work (an operation) in a ChangePlan.
Binds: data-model.md 5, INV-O1, INV-O2, FR-065, FR-066.
Constructors
- Operation({required OperationKind kind, required String logicalPath, required String contentHash, required OwnershipClass ownershipClass, String? idempotencyKey})
-
Operation.fromJson(Map<
String, dynamic> json) -
factory
Properties
- contentHash → String
-
final
- hashCode → int
-
The hash code for this object.
no setterinherited
- idempotencyKey → String
-
final
- kind → OperationKind
-
final
- logicalPath → String
-
final
- ownershipClass → OwnershipClass
-
final
- runtimeType → Type
-
A representation of the runtime type of the object.
no setterinherited
Methods
-
noSuchMethod(
Invocation invocation) → dynamic -
Invoked when a nonexistent method or property is accessed.
inherited
-
toJson(
) → Map< String, dynamic> -
toString(
) → String -
A string representation of this object.
inherited
Operators
-
operator ==(
Object other) → bool -
The equality operator.
inherited