ToolchainException class
Represents a toolchain exception indicating a file is host-path-dependent.
Binds: INV-C5, FR-100.
Constructors
- ToolchainException({required String logicalPath, required String reason, required String regeneratedBy})
-
ToolchainException.fromJson(Map<
String, dynamic> json) -
factory
Properties
- hashCode → int
-
The hash code for this object.
no setterinherited
- logicalPath → String
-
final
- reason → String
-
final
- regeneratedBy → String
-
final
- runtimeType → Type
-
A representation of the runtime type of the object.
no setterinherited
Methods
-
noSuchMethod(
Invocation invocation) → dynamic -
Invoked when a nonexistent method or property is accessed.
inherited
-
toJson(
) → Map< String, dynamic> -
toString(
) → String -
A string representation of this object.
inherited
Operators
-
operator ==(
Object other) → bool -
The equality operator.
inherited