ComposedResult class
A single deterministic, de-duplicated, dependency-ordered composed unit (data-model.md 6). The composer's output — not a new type over Contribution.
Constructors
-
ComposedResult({required List<
Operation> fileOperations, required List<Contribution> dependencyContributions, required List<Contribution> registrationContributions, required List<Contribution> initContributions}) -
const
Properties
-
dependencyContributions
→ List<
Contribution> -
final
-
fileOperations
→ List<
Operation> -
final
- hashCode → int
-
The hash code for this object.
no setterinherited
-
initContributions
→ List<
Contribution> -
final
-
registrationContributions
→ List<
Contribution> -
final
- runtimeType → Type
-
A representation of the runtime type of the object.
no setterinherited
Methods
-
noSuchMethod(
Invocation invocation) → dynamic -
Invoked when a nonexistent method or property is accessed.
inherited
-
toString(
) → String -
A string representation of this object.
inherited
Operators
-
operator ==(
Object other) → bool -
The equality operator.
inherited